# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_apps.post import CreateApp
from onelogin.paths.api_2_apps_app_id.delete import DeleteApp
from onelogin.paths.api_2_apps_app_id_parameters_parameter_id.delete import DeleteAppParameter
from onelogin.paths.api_2_apps_app_id.get import GetApp
from onelogin.paths.api_2_apps_app_id_users.get import GetAppUsers
from onelogin.paths.api_2_apps.get import ListApps
from onelogin.paths.api_2_connectors.get import ListConnectors
from onelogin.paths.api_2_apps_app_id.put import UpdateApp


class AppsApi(
    CreateApp,
    DeleteApp,
    DeleteAppParameter,
    GetApp,
    GetAppUsers,
    ListApps,
    ListConnectors,
    UpdateApp,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
