from onelogin.paths.api_2_apps_app_id_rules.get import ApiForget
from onelogin.paths.api_2_apps_app_id_rules.post import ApiForpost


class Api2AppsAppIdRules(
    ApiForget,
    ApiForpost,
):
    pass
