from onelogin.paths.api_2_api_authorizations_api_auth_id_claims.get import ApiForget
from onelogin.paths.api_2_api_authorizations_api_auth_id_claims.post import ApiForpost


class Api2ApiAuthorizationsApiAuthIdClaims(
    ApiForget,
    ApiForpost,
):
    pass
