from onelogin.paths.api_2_branding_brands_brand_id_templates.get import ApiForget
from onelogin.paths.api_2_branding_brands_brand_id_templates.post import ApiForpost


class Api2BrandingBrandsBrandIdTemplates(
    ApiForget,
    ApiForpost,
):
    pass
