from onelogin.paths.api_1_users_user_id.get import ApiForget
from onelogin.paths.api_1_users_user_id.put import ApiForput
from onelogin.paths.api_1_users_user_id.delete import ApiFordelete


class Api1UsersUserId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
