# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class Verb(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Verbs are used to distinguish between different types of events. Where possible use one of the following verbs to describe the event. Alternately you can create custom verbs to describe other types of actions within your application.
    """


    class MetaOapg:
        enum_value_to_name = {
            "log-in": "LOGIN",
            "log-out": "LOGOUT",
            "log-in-denied": "LOGINDENIED",
            "authentication-challenge": "AUTHENTICATIONCHALLENGE",
            "authentication-challenge-pass": "AUTHENTICATIONCHALLENGEPASS",
            "authentication-challenge-fail": "AUTHENTICATIONCHALLENGEFAIL",
        }
    
    @schemas.classproperty
    def LOGIN(cls):
        return cls("log-in")
    
    @schemas.classproperty
    def LOGOUT(cls):
        return cls("log-out")
    
    @schemas.classproperty
    def LOGINDENIED(cls):
        return cls("log-in-denied")
    
    @schemas.classproperty
    def AUTHENTICATIONCHALLENGE(cls):
        return cls("authentication-challenge")
    
    @schemas.classproperty
    def AUTHENTICATIONCHALLENGEPASS(cls):
        return cls("authentication-challenge-pass")
    
    @schemas.classproperty
    def AUTHENTICATIONCHALLENGEFAIL(cls):
        return cls("authentication-challenge-fail")
