# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from onelogin.paths.api_1_users_set_password_using_salt_user_id import Api

from onelogin.paths import PathValues

path = PathValues.API_1_USERS_SET_PASSWORD_USING_SALT_USER_ID