from onelogin.paths.api_2_roles_role_id_apps.get import ApiForget
from onelogin.paths.api_2_roles_role_id_apps.put import ApiForput


class Api2RolesRoleIdApps(
    ApiForget,
    ApiForput,
):
    pass
