# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_api_authorizations.post import CreateAuthServer
from onelogin.paths.api_2_api_authorizations_api_auth_id.delete import DeleteAuthServer
from onelogin.paths.api_2_api_authorizations_api_auth_id.get import GetAuthServer
from onelogin.paths.api_2_api_authorizations.get import ListAuthServers
from onelogin.paths.api_2_api_authorizations_api_auth_id.put import UpdateAuthServer


class APIAuthorizationServerApi(
    CreateAuthServer,
    DeleteAuthServer,
    GetAuthServer,
    ListAuthServers,
    UpdateAuthServer,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
