# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_api_authorizations_api_auth_id_clients.post import AddClientApp
from onelogin.paths.api_2_api_authorizations_api_auth_id_clients_client_app_id.delete import DeleteClientApp
from onelogin.paths.api_2_api_authorizations_api_auth_id_clients.get import ListClientApps
from onelogin.paths.api_2_api_authorizations_api_auth_id_clients_client_app_id.put import UpdateClientApp


class APIAuthClientAppsApi(
    AddClientApp,
    DeleteClientApp,
    ListClientApps,
    UpdateClientApp,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
