# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_hooks_envs.post import CreateEnvironmentVariable
from onelogin.paths.api_2_hooks.post import CreateHook
from onelogin.paths.api_2_hooks_envs_envvar_id.delete import DeleteEnvironmentVariable
from onelogin.paths.api_2_hooks_hook_id.delete import DeleteHook
from onelogin.paths.api_2_hooks_envs_envvar_id.get import GetEnvironmentVariable
from onelogin.paths.api_2_hooks_hook_id.get import GetHook
from onelogin.paths.api_2_hooks_hook_id_logs.get import GetLogs
from onelogin.paths.api_2_hooks_envs.get import ListEnvironmentVariables
from onelogin.paths.api_2_hooks.get import ListHooks
from onelogin.paths.api_2_hooks_envs_envvar_id.put import UpdateEnvironmentVariable
from onelogin.paths.api_2_hooks_hook_id.put import UpdateHook


class SmartHooksApi(
    CreateEnvironmentVariable,
    CreateHook,
    DeleteEnvironmentVariable,
    DeleteHook,
    GetEnvironmentVariable,
    GetHook,
    GetLogs,
    ListEnvironmentVariables,
    ListHooks,
    UpdateEnvironmentVariable,
    UpdateHook,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
