# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.auth_oauth2_v2_token.post import GenerateToken
from onelogin.paths.auth_rate_limit.get import GetRateLimit
from onelogin.paths.auth_oauth2_revoke.post import RevokeTokens


class OAuth2Api(
    GenerateToken,
    GetRateLimit,
    RevokeTokens,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
