# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_mfa_users_user_id_verifications.post import CreateDeviceVerification
from onelogin.paths.api_2_mfa_users_user_id_registrations.post import CreateFactorRegistration
from onelogin.paths.api_2_mfa_users_user_id_devices_device_id.delete import DeleteEnrolledFactor
from onelogin.paths.api_2_mfa_users_user_id_mfa_token.post import GenerateOtp
from onelogin.paths.api_2_mfa_users_user_id_factors.get import GetAuthFactors
from onelogin.paths.api_2_mfa_users_user_id_devices.get import GetAuthenticationDevices
from onelogin.paths.api_2_mfa_users_user_id_registrations_registration_id.get import GetUserRegistration
from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.get import GetUserVerification
from onelogin.paths.api_2_mfa_users_user_id_registrations_registration_id.put import VerifyUserRegistration
from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.put import VerifyUserVerification


class MultiFactorAuthenticationApi(
    CreateDeviceVerification,
    CreateFactorRegistration,
    DeleteEnrolledFactor,
    GenerateOtp,
    GetAuthFactors,
    GetAuthenticationDevices,
    GetUserRegistration,
    GetUserVerification,
    VerifyUserRegistration,
    VerifyUserVerification,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
