from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.get import ApiForget
from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.put import ApiForput


class Api2MfaUsersUserIdVerificationsVerificationId(
    ApiForget,
    ApiForput,
):
    pass
