# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_branding_brands_brand_id_templates.post import CreateMessageTemplate
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_id.delete import DeleteMessageTemplate
from onelogin.paths.api_2_branding_brands_master_templates_template_type.get import GetMasterByType
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_id.get import GetMessageTemplateById
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.get import GetTemplateByLocale
from onelogin.paths.api_2_branding_brands_brand_id_templates.get import ListMessageTemplates
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_id.put import UpdateMessageTemplateById
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.put import UpdateTemplateByLocale


class BrandingServiceTemplatesApi(
    CreateMessageTemplate,
    DeleteMessageTemplate,
    GetMasterByType,
    GetMessageTemplateById,
    GetTemplateByLocale,
    ListMessageTemplates,
    UpdateMessageTemplateById,
    UpdateTemplateByLocale,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
