# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_saml_assertion.post import GenerateSamlAssert
from onelogin.paths.api_2_saml_assertion.post import GenerateSamlAssert2
from onelogin.paths.api_1_saml_assertion_verify_factor.post import VerFactorSaml
from onelogin.paths.api_2_saml_assertion_verify_factor.post import VerFactorSaml2


class SAMLAssertionsApi(
    GenerateSamlAssert,
    GenerateSamlAssert2,
    VerFactorSaml,
    VerFactorSaml2,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
