# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_branding_brands.post import CreateBrand
from onelogin.paths.api_2_branding_brands_brand_id.delete import DeleteBrand
from onelogin.paths.api_2_branding_brands_brand_id.get import GetBrand
from onelogin.paths.api_2_branding_brands_brand_id_apps.get import GetBrandApps
from onelogin.paths.api_2_branding_brands.get import ListBrands
from onelogin.paths.api_2_branding_brands_brand_id.put import UpdateBrand


class BrandingServiceApi(
    CreateBrand,
    DeleteBrand,
    GetBrand,
    GetBrandApps,
    ListBrands,
    UpdateBrand,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
