# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_privileges_privilege_id_roles.post import AddPrivilegeToRole
from onelogin.paths.api_1_privileges_privilege_id_users.post import AssignUsersToPrivilege
from onelogin.paths.api_1_privileges.post import CreatePrivilege
from onelogin.paths.api_1_privileges_privilege_id.delete import DeletePrivilege
from onelogin.paths.api_1_privileges_privilege_id_roles_role_id.delete import DeleteRoleFromPrivilege
from onelogin.paths.api_1_privileges_privilege_id_users.get import GetAssignedUser
from onelogin.paths.api_1_privileges_privilege_id.get import GetPrivilege
from onelogin.paths.api_1_privileges_privilege_id_roles.get import ListPrivilegeRoles
from onelogin.paths.api_1_privileges.get import ListPrivileges
from onelogin.paths.api_1_privileges_privilege_id_users_user_id.delete import RemoveUserFromPrivilege
from onelogin.paths.api_1_privileges_privilege_id.put import UpdatePrivilege


class PrivilegesApi(
    AddPrivilegeToRole,
    AssignUsersToPrivilege,
    CreatePrivilege,
    DeletePrivilege,
    DeleteRoleFromPrivilege,
    GetAssignedUser,
    GetPrivilege,
    ListPrivilegeRoles,
    ListPrivileges,
    RemoveUserFromPrivilege,
    UpdatePrivilege,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
