from onelogin.paths.api_2_risk_rules_rule_id.get import ApiForget
from onelogin.paths.api_2_risk_rules_rule_id.put import ApiForput
from onelogin.paths.api_2_risk_rules_rule_id.delete import ApiFordelete


class Api2RiskRulesRuleId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
