# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

import unittest

import onelogin
from onelogin.model.clock_counter import ClockCounter
from onelogin import configuration


class TestClockCounter(unittest.TestCase):
    """ClockCounter unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
