# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes.post import CreateScope
from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes_scope_id.delete import DeleteScope
from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes.get import GetScopes
from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes_scope_id.put import UpdateScope


class APIAuthScopesApi(
    CreateScope,
    DeleteScope,
    GetScopes,
    UpdateScope,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
