from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.get import ApiForget
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.put import ApiForput


class Api2BrandingBrandsBrandIdTemplatesTemplateTypeLocale(
    ApiForget,
    ApiForput,
):
    pass
