from onelogin.paths.api_1_privileges_privilege_id_users.get import ApiForget
from onelogin.paths.api_1_privileges_privilege_id_users.post import ApiForpost


class Api1PrivilegesPrivilegeIdUsers(
    ApiForget,
    ApiForpost,
):
    pass
