# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_risk_rules.post import CreateRiskRule
from onelogin.paths.api_2_risk_rules_rule_id.delete import DeleteRiskRule
from onelogin.paths.api_2_risk_rules_rule_id.get import GetRiskRule
from onelogin.paths.api_2_risk_verify.post import GetRiskScore
from onelogin.paths.api_2_risk_scores.get import GetRiskScores
from onelogin.paths.api_2_risk_rules.get import ListRiskRules
from onelogin.paths.api_2_risk_events.post import TrackRiskEvent
from onelogin.paths.api_2_risk_rules_rule_id.put import UpdateRiskRule


class VigilanceAIApi(
    CreateRiskRule,
    DeleteRiskRule,
    GetRiskRule,
    GetRiskScore,
    GetRiskScores,
    ListRiskRules,
    TrackRiskEvent,
    UpdateRiskRule,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
