from onelogin.paths.api_1_privileges_privilege_id_roles.get import ApiForget
from onelogin.paths.api_1_privileges_privilege_id_roles.post import ApiForpost


class Api1PrivilegesPrivilegeIdRoles(
    ApiForget,
    ApiForpost,
):
    pass
