# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_users.post import CreateUser2
from onelogin.paths.api_2_users_user_id.delete import DeleteUser2
from onelogin.paths.api_2_users_user_id.get import GetUser2
from onelogin.paths.api_2_users_user_id_apps.get import GetUserApps2
from onelogin.paths.api_2_users.get import ListUsers2
from onelogin.paths.api_2_users_user_id.put import UpdateUser2


class UsersV2Api(
    CreateUser2,
    DeleteUser2,
    GetUser2,
    GetUserApps2,
    ListUsers2,
    UpdateUser2,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
