# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_users_user_id_otp_devices_device_id_trigger.post import ActivateMfaFactors
from onelogin.paths.api_1_users_user_id_otp_devices.post import EnrollMfaFactor
from onelogin.paths.api_1_users_user_id_mfa_token.post import GenerateMfAtoken
from onelogin.paths.api_1_users_user_id_otp_devices.get import GetEnrolledFactors
from onelogin.paths.api_1_users_user_id_auth_factor.get import GetMfaFactors
from onelogin.paths.api_1_users_user_id_otp_devices_device_id.delete import RemoveMfaFactors
from onelogin.paths.api_1_users_user_id_otp_devices_device_id_verify.post import VerifyMfaFactor


class MultiFactorAuthenticationV1Api(
    ActivateMfaFactors,
    EnrollMfaFactor,
    GenerateMfAtoken,
    GetEnrolledFactors,
    GetMfaFactors,
    RemoveMfaFactors,
    VerifyMfaFactor,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
