# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_roles_role_id_admins.post import AddRoleAdmins
from onelogin.paths.api_2_roles_role_id_users.post import AddRoleUsers
from onelogin.paths.api_2_roles.post import CreateRole
from onelogin.paths.api_2_roles_role_id.delete import DeleteRole
from onelogin.paths.api_2_roles_role_id.get import GetRole
from onelogin.paths.api_2_roles_role_id_admins.get import GetRoleAdmins
from onelogin.paths.api_2_roles_role_id_apps.get import GetRoleApps
from onelogin.paths.api_1_roles_role_id.get import GetRoleById
from onelogin.paths.api_1_roles.get import GetRoleByName
from onelogin.paths.api_2_roles_role_id_users.get import GetRoleUsers
from onelogin.paths.api_2_roles.get import ListRoles
from onelogin.paths.api_2_roles_role_id_admins.delete import RemoveRoleAdmins
from onelogin.paths.api_2_roles_role_id_users.delete import RemoveRoleUsers
from onelogin.paths.api_2_roles_role_id_apps.put import SetRoleApps
from onelogin.paths.api_2_roles_role_id.put import UpdateRole


class RolesApi(
    AddRoleAdmins,
    AddRoleUsers,
    CreateRole,
    DeleteRole,
    GetRole,
    GetRoleAdmins,
    GetRoleApps,
    GetRoleById,
    GetRoleByName,
    GetRoleUsers,
    ListRoles,
    RemoveRoleAdmins,
    RemoveRoleUsers,
    SetRoleApps,
    UpdateRole,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
