from onelogin.paths.api_1_users_user_id_otp_devices.get import ApiForget
from onelogin.paths.api_1_users_user_id_otp_devices.post import ApiForpost


class Api1UsersUserIdOtpDevices(
    ApiForget,
    ApiForpost,
):
    pass
