from onelogin.paths.api_2_api_authorizations_api_auth_id_clients.get import ApiForget
from onelogin.paths.api_2_api_authorizations_api_auth_id_clients.post import ApiForpost


class Api2ApiAuthorizationsApiAuthIdClients(
    ApiForget,
    ApiForpost,
):
    pass
