from onelogin.paths.api_2_api_authorizations_api_auth_id.get import ApiForget
from onelogin.paths.api_2_api_authorizations_api_auth_id.put import ApiForput
from onelogin.paths.api_2_api_authorizations_api_auth_id.delete import ApiFordelete


class Api2ApiAuthorizationsApiAuthId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
