# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from onelogin.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    AUTH_OAUTH2_V2_TOKEN = "/auth/oauth2/v2/token"
    AUTH_OAUTH2_REVOKE = "/auth/oauth2/revoke"
    AUTH_RATE_LIMIT = "/auth/rate_limit"
    API_2_API_AUTHORIZATIONS = "/api/2/api_authorizations"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID = "/api/2/api_authorizations/{api_auth_id}"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES = "/api/2/api_authorizations/{api_auth_id}/scopes"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES_SCOPE_ID = "/api/2/api_authorizations/{api_auth_id}/scopes/{scope_id}"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS = "/api/2/api_authorizations/{api_auth_id}/claims"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS_CLAIM_ID = "/api/2/api_authorizations/{api_auth_id}/claims/{claim_id}"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS = "/api/2/api_authorizations/{api_auth_id}/clients"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS_CLIENT_APP_ID = "/api/2/api_authorizations/{api_auth_id}/clients/{client_app_id}"
    API_1_EVENTS = "/api/1/events"
    API_1_EVENTS_EVENT_ID = "/api/1/events/{event_id}"
    API_1_EVENTS_TYPES = "/api/1/events/types"
    API_1_GROUPS = "/api/1/groups"
    API_1_GROUPS_GROUP_ID = "/api/1/groups/{group_id}"
    API_1_INVITES_GET_INVITE_LINK = "/api/1/invites/get_invite_link"
    API_1_INVITES_SEND_INVITE_LINK = "/api/1/invites/send_invite_link"
    API_1_USERS = "/api/1/users"
    API_1_USERS_USER_ID = "/api/1/users/{user_id}"
    API_1_USERS_USER_ID_APPS = "/api/1/users/{user_id}/apps"
    API_1_USERS_USER_ID_ROLES = "/api/1/users/{user_id}/roles"
    API_1_USERS_SET_PASSWORD_CLEAR_TEXT_USER_ID = "/api/1/users/set_password_clear_text/{user_id}"
    API_1_USERS_SET_PASSWORD_USING_SALT_USER_ID = "/api/1/users/set_password_using_salt/{user_id}"
    API_1_USERS_CUSTOM_ATTRIBUTES = "/api/1/users/custom_attributes"
    API_1_USERS_USER_ID_AUTH_FACTOR = "/api/1/users/{user_id}/auth_factor"
    API_1_USERS_USER_ID_LOGOUT = "/api/1/users/{user_id}/logout"
    API_1_USERS_USER_ID_LOCK_USER = "/api/1/users/{user_id}/lock_user"
    API_1_USERS_USER_ID_OTP_DEVICES = "/api/1/users/{user_id}/otp_devices"
    API_1_USERS_USER_ID_MFA_TOKEN = "/api/1/users/{user_id}/mfa_token"
    API_1_USERS_USER_ID_ADD_ROLES = "/api/1/users/{user_id}/add_roles"
    API_1_USERS_USER_ID_SET_STATE = "/api/1/users/{user_id}/set_state"
    API_1_USERS_USER_ID_REMOVE_ROLES = "/api/1/users/{user_id}/remove_roles"
    API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID = "/api/1/users/{user_id}/otp_devices/{device_id}"
    API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_VERIFY = "/api/1/users/{user_id}/otp_devices/{device_id}/verify"
    API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_TRIGGER = "/api/1/users/{user_id}/otp_devices/{device_id}/trigger"
    API_1_PRIVILEGES = "/api/1/privileges"
    API_1_PRIVILEGES_PRIVILEGE_ID = "/api/1/privileges/{privilege_id}"
    API_1_PRIVILEGES_PRIVILEGE_ID_ROLES = "/api/1/privileges/{privilege_id}/roles"
    API_1_PRIVILEGES_PRIVILEGE_ID_ROLES_ROLE_ID = "/api/1/privileges/{privilege_id}/roles/{role_id}"
    API_1_PRIVILEGES_PRIVILEGE_ID_USERS = "/api/1/privileges/{privilege_id}/users"
    API_1_PRIVILEGES_PRIVILEGE_ID_USERS_USER_ID = "/api/1/privileges/{privilege_id}/users/{user_id}"
    API_1_ROLES = "/api/1/roles"
    API_1_ROLES_ROLE_ID = "/api/1/roles/{role_id}"
    API_1_SAML_ASSERTION = "/api/1/saml_assertion"
    API_1_SAML_ASSERTION_VERIFY_FACTOR = "/api/1/saml_assertion/verify_factor"
    API_2_SAML_ASSERTION = "/api/2/saml_assertion"
    API_2_SAML_ASSERTION_VERIFY_FACTOR = "/api/2/saml_assertion/verify_factor"
    API_2_MAPPINGS = "/api/2/mappings"
    API_2_MAPPINGS_MAPPING_ID = "/api/2/mappings/{mapping_id}"
    API_2_MAPPINGS_CONDITIONS = "/api/2/mappings/conditions"
    API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_OPERATORS = "/api/2/mappings/conditions/{mapping_condition_value}/operators"
    API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_VALUES = "/api/2/mappings/conditions/{mapping_condition_value}/values"
    API_2_MAPPINGS_ACTIONS = "/api/2/mappings/actions"
    API_2_MAPPINGS_ACTIONS_MAPPING_ACTION_VALUE_VALUES = "/api/2/mappings/actions/{mapping_action_value}/values"
    API_2_MAPPINGS_SORT = "/api/2/mappings/sort"
    API_2_APPS = "/api/2/apps"
    API_2_APPS_APP_ID = "/api/2/apps/{app_id}"
    API_2_APPS_APP_ID_PARAMETERS_PARAMETER_ID = "/api/2/apps/{app_id}/parameters/{parameter_id}"
    API_2_APPS_APP_ID_USERS = "/api/2/apps/{app_id}/users"
    API_2_APPS_APP_ID_RULES = "/api/2/apps/{app_id}/rules"
    API_2_APPS_APP_ID_RULES_RULE_ID = "/api/2/apps/{app_id}/rules/{rule_id}"
    API_2_APPS_APP_ID_RULES_CONDITIONS = "/api/2/apps/{app_id}/rules/conditions"
    API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_OPERATORS = "/api/2/apps/{app_id}/rules/conditions/{rule_condition_value}/operators"
    API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_VALUES = "/api/2/apps/{app_id}/rules/conditions/{rule_condition_value}/values"
    API_2_APPS_APP_ID_RULES_ACTIONS = "/api/2/apps/{app_id}/rules/actions"
    API_2_APPS_APP_ID_RULES_ACTIONS_RULE_ACTION_VALUE_VALUES = "/api/2/apps/{app_id}/rules/actions/{rule_action_value}/values"
    API_2_APPS_APP_ID_RULES_SORT = "/api/2/apps/{app_id}/rules/sort"
    API_2_CONNECTORS = "/api/2/connectors"
    API_2_RISK_RULES = "/api/2/risk/rules"
    API_2_RISK_RULES_RULE_ID = "/api/2/risk/rules/{rule_id}"
    API_2_RISK_EVENTS = "/api/2/risk/events"
    API_2_RISK_SCORES = "/api/2/risk/scores"
    API_2_RISK_VERIFY = "/api/2/risk/verify"
    API_2_MFA_USERS_USER_ID_REGISTRATIONS_REGISTRATION_ID = "/api/2/mfa/users/{user_id}/registrations/{registration_id}"
    API_2_MFA_USERS_USER_ID_REGISTRATIONS = "/api/2/mfa/users/{user_id}/registrations"
    API_2_MFA_USERS_USER_ID_DEVICES = "/api/2/mfa/users/{user_id}/devices"
    API_2_MFA_USERS_USER_ID_DEVICES_DEVICE_ID = "/api/2/mfa/users/{user_id}/devices/{device_id}"
    API_2_MFA_USERS_USER_ID_VERIFICATIONS_VERIFICATION_ID = "/api/2/mfa/users/{user_id}/verifications/{verification_id}"
    API_2_MFA_USERS_USER_ID_VERIFICATIONS = "/api/2/mfa/users/{user_id}/verifications"
    API_2_MFA_USERS_USER_ID_FACTORS = "/api/2/mfa/users/{user_id}/factors"
    API_2_MFA_USERS_USER_ID_MFA_TOKEN = "/api/2/mfa/users/{user_id}/mfa_token"
    API_2_ROLES = "/api/2/roles"
    API_2_ROLES_ROLE_ID = "/api/2/roles/{role_id}"
    API_2_ROLES_ROLE_ID_APPS = "/api/2/roles/{role_id}/apps"
    API_2_ROLES_ROLE_ID_USERS = "/api/2/roles/{role_id}/users"
    API_2_ROLES_ROLE_ID_ADMINS = "/api/2/roles/{role_id}/admins"
    API_2_HOOKS = "/api/2/hooks"
    API_2_HOOKS_HOOK_ID = "/api/2/hooks/{hook_id}"
    API_2_HOOKS_HOOK_ID_LOGS = "/api/2/hooks/{hook_id}/logs"
    API_2_HOOKS_ENVS = "/api/2/hooks/envs"
    API_2_HOOKS_ENVS_ENVVAR_ID = "/api/2/hooks/envs/{envvar_id}"
    API_2_USERS = "/api/2/users"
    API_2_USERS_USER_ID = "/api/2/users/{user_id}"
    API_2_USERS_USER_ID_APPS = "/api/2/users/{user_id}/apps"
    API_2_BRANDING_BRANDS = "/api/2/branding/brands"
    API_2_BRANDING_BRANDS_BRAND_ID = "/api/2/branding/brands/{brand_id}"
    API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES = "/api/2/branding/brands/{brand_id}/templates"
    API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_ID = "/api/2/branding/brands/{brand_id}/templates/{template_id}"
    API_2_BRANDING_BRANDS_BRAND_ID_APPS = "/api/2/branding/brands/{brand_id}/apps"
    API_2_BRANDING_EMAIL_SETTINGS = "/api/2/branding/email_settings"
    API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_TYPE_LOCALE = "/api/2/branding/brands/{brand_id}/templates/{template_type}/{locale}"
    API_2_BRANDING_BRANDS_MASTER_TEMPLATES_TEMPLATE_TYPE = "/api/2/branding/brands/master/templates/{template_type}"
