# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_users_user_id_add_roles.put import AddRolesToUser
from onelogin.paths.api_1_users.post import CreateUser
from onelogin.paths.api_1_users_user_id.delete import DeleteUser
from onelogin.paths.api_1_users_custom_attributes.get import GetCustomAttributes
from onelogin.paths.api_1_users_user_id_apps.get import GetUserApps
from onelogin.paths.api_1_users_user_id.get import GetUserById
from onelogin.paths.api_1_users_user_id_roles.get import GetUserRoles
from onelogin.paths.api_1_users.get import ListUsers
from onelogin.paths.api_1_users_user_id_lock_user.put import LockAccountUser
from onelogin.paths.api_1_users_user_id_logout.put import LogOutUser
from onelogin.paths.api_1_users_user_id_remove_roles.put import RemoveUserRole
from onelogin.paths.api_1_users_user_id_set_state.put import SetUserState
from onelogin.paths.api_1_users_set_password_clear_text_user_id.put import UpdatePasswordInsecure
from onelogin.paths.api_1_users_set_password_using_salt_user_id.put import UpdatePasswordSecure
from onelogin.paths.api_1_users_user_id.put import UpdateUser


class UsersV1Api(
    AddRolesToUser,
    CreateUser,
    DeleteUser,
    GetCustomAttributes,
    GetUserApps,
    GetUserById,
    GetUserRoles,
    ListUsers,
    LockAccountUser,
    LogOutUser,
    RemoveUserRole,
    SetUserState,
    UpdatePasswordInsecure,
    UpdatePasswordSecure,
    UpdateUser,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
