# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_apps_app_id_rules.post import CreateAppRule
from onelogin.paths.api_2_apps_app_id_rules_rule_id.delete import DeleteRule
from onelogin.paths.api_2_apps_app_id_rules_rule_id.get import GetAppRule
from onelogin.paths.api_2_apps_app_id_rules_actions_rule_action_value_values.get import ListActionValies
from onelogin.paths.api_2_apps_app_id_rules_actions.get import ListActions
from onelogin.paths.api_2_apps_app_id_rules.get import ListAppRules
from onelogin.paths.api_2_apps_app_id_rules_conditions_rule_condition_value_operators.get import ListConditionOperators
from onelogin.paths.api_2_apps_app_id_rules_conditions_rule_condition_value_values.get import ListConditionValues
from onelogin.paths.api_2_apps_app_id_rules_conditions.get import ListConditions
from onelogin.paths.api_2_apps_app_id_rules_sort.put import SortAppRules
from onelogin.paths.api_2_apps_app_id_rules_rule_id.put import UpdateAppRule


class AppRulesApi(
    CreateAppRule,
    DeleteRule,
    GetAppRule,
    ListActionValies,
    ListActions,
    ListAppRules,
    ListConditionOperators,
    ListConditionValues,
    ListConditions,
    SortAppRules,
    UpdateAppRule,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
