from onelogin.paths.api_2_api_authorizations.get import ApiForget
from onelogin.paths.api_2_api_authorizations.post import ApiForpost


class Api2ApiAuthorizations(
    ApiForget,
    ApiForpost,
):
    pass
