# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from onelogin.paths.api_2_roles_role_id_users import Api

from onelogin.paths import PathValues

path = PathValues.API_2_ROLES_ROLE_ID_USERS